package REAPI;
import java.io.File;
import java.io.UnsupportedEncodingException;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLEncoder;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.logging.Logger;

import org.eclipse.birt.report.engine.api.EngineConstants;
import org.eclipse.birt.report.engine.api.HTMLActionHandler;
import org.eclipse.birt.report.engine.api.HTMLRenderContext;
import org.eclipse.birt.report.engine.api.IAction;
import org.eclipse.birt.report.engine.api.IHTMLActionHandler;
import org.eclipse.birt.report.engine.api.PDFRenderContext;
import org.eclipse.birt.report.engine.api.script.IReportContext;
import org.eclipse.birt.report.model.api.util.ParameterValidationUtil;

import com.ibm.icu.math.BigDecimal;

/**
 * Defines a default action handler for HTML output format
 */
public class MyFileActionHandler implements IHTMLActionHandler
{

	/** logger */
	protected Logger log = Logger
	.getLogger( HTMLActionHandler.class.getName( ) );

	public String getURL( IAction actionDefn, Object context )
	{
		return null;
	}

	/**
	 * builds URL for drillthrough action
	 * 
	 * @param action
	 *            instance of the IAction instance
	 * @param context
	 *            the context for building the action string
	 * @return a URL
	 */
	protected String buildDrillAction( IAction action, IReportContext rcontext )
	{
		String baseURL = null;
		if ( rcontext != null )
		{
			baseURL = rcontext.getRenderOption().getBaseURL();
		}
		
		StringBuffer link = new StringBuffer( );
		String reportName = action.getReportName( );

		if ( reportName != null && !reportName.equals( "" ) ) //$NON-NLS-1$
		{

			link.append( baseURL );
			link.append("/");
			String outformat = "."+rcontext.getOutputFormat();
            String outputname = reportName.replaceFirst(".rptdesign", outformat);
			link.append( outputname );
			if (action.getBookmark( ) != null )
			{

				link.append( "#" ); //$NON-NLS-1$
				String bmk = action.getBookmark( );
				link.append( bmk );
			}
		}

		return link.toString( );
	}

	public String getURL( IAction actionDefn, IReportContext context )
	{
		if ( actionDefn == null )
		{
			return null;
		}
		String url = null;
		switch ( actionDefn.getType( ) )
		{
		case IAction.ACTION_BOOKMARK :
			if ( actionDefn.getActionString( ) != null )
			{
				url = "#" + actionDefn.getActionString( );
			}
			break;
		case IAction.ACTION_HYPERLINK :
			url = actionDefn.getActionString( );
			break;
		case IAction.ACTION_DRILLTHROUGH :
			url = buildDrillAction( actionDefn, context );
			break;
		default :
			return null;
		}
		return url;
	}
	protected Object getRenderContext( IReportContext context )
	{
		if ( context == null )
		{
			return null;
		}
		Map appContext = context.getAppContext( );
		if ( appContext != null )
		{
			String renderContextKey = EngineConstants.APPCONTEXT_HTML_RENDER_CONTEXT;
			String format = context.getOutputFormat( );
			if ( "pdf".equalsIgnoreCase( format ) )
			{
				renderContextKey = EngineConstants.APPCONTEXT_PDF_RENDER_CONTEXT;
			}
			return appContext.get( renderContextKey );
		}
		
		return null;
	}

}